if [ ! -e /etc/discusrc ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/discusrc /etc/discusrc
fi

